@@ -206,3 +206,123 @@ class InvoicesListFilter(BaseModel):
     status: Optional[str] = None
     limit: Optional[int] = Field(default=50, ge=1, le=200)
     cursor: Optional[str] = None
+
+
+class SetupIntentOut(BaseModel):
+    id: str
+    provider: str
+    provider_setup_intent_id: str
+    status: str
+    client_secret: Optional[str] = None
+    next_action: Optional[NextAction] = None
+
+
+class DisputeOut(BaseModel):
+    id: str
+    provider: str
+    provider_dispute_id: str
+    amount: AmountMinor
+    currency: Currency
+    reason: Optional[str] = None
+    status: str
+    evidence_due_by: Optional[str] = None
+    created_at: Optional[str] = None
+
+
+class PayoutOut(BaseModel):
+    id: str
+    provider: str
+    provider_payout_id: str
+    amount: AmountMinor
+    currency: Currency
+    status: str
+    arrival_date: Optional[str] = None
+    type: Optional[str] = None
+
+
+class BalanceAmount(BaseModel):
+    currency: Currency
+    amount: AmountMinor
+
+
+class BalanceSnapshotOut(BaseModel):
+    available: list[BalanceAmount] = Field(default_factory=list)
+    pending: list[BalanceAmount] = Field(default_factory=list)
+
+
+class SetupIntentCreateIn(BaseModel):
+    payment_method_types: list[str] = Field(default_factory=lambda: ["card"])
+
+
+class WebhookReplayOut(BaseModel):
+    replayed: int
+
+
+class WebhookAckOut(BaseModel):
+    ok: bool
+
+
+class UsageRecordOut(BaseModel):
+    id: str
+    quantity: int
+    timestamp: Optional[int] = None
+    subscription_item: Optional[str] = None
+    provider_price_id: Optional[str] = None
+
+
+# -------- Customers list filter ----------
+class CustomersListFilter(BaseModel):
+    provider: Optional[str] = None
+    user_id: Optional[str] = None
+    limit: Optional[int] = Field(default=50, ge=1, le=200)
+    cursor: Optional[str] = None  # we’ll paginate on provider_customer_id asc
+
+
+# -------- Products / Prices updates ----------
+class ProductUpdateIn(BaseModel):
+    name: Optional[str] = None
+    active: Optional[bool] = None
+
+
+class PriceUpdateIn(BaseModel):
+    active: Optional[bool] = None
+
+
+# -------- Payment Method update ----------
+class PaymentMethodUpdateIn(BaseModel):
+    # keep minimal + commonly supported card fields
+    name: Optional[str] = None
+    exp_month: Optional[int] = None
+    exp_year: Optional[int] = None
+    # extend here later with address fields (line1, city, etc.)
+
+
+# -------- Refunds (list/get) ----------
+class RefundOut(BaseModel):
+    id: str
+    provider: str
+    provider_refund_id: str
+    provider_payment_intent_id: Optional[str] = None
+    amount: AmountMinor
+    currency: Currency
+    status: str
+    reason: Optional[str] = None
+    created_at: Optional[str] = None
+
+
+# -------- Invoice line items (list) ----------
+class InvoiceLineItemOut(BaseModel):
+    id: str
+    description: Optional[str] = None
+    amount: AmountMinor
+    currency: Currency
+    quantity: Optional[int] = 1
+    provider_price_id: Optional[str] = None
+
+
+# -------- Usage records list/get ----------
+class UsageRecordListFilter(BaseModel):
+    subscription_item: Optional[str] = None
+    provider_price_id: Optional[str] = None
+    limit: Optional[int] = Field(default=50, ge=1, le=200)
+    cursor: Optional[str] = None
