@@ -5,6 +5,10 @@ from typing import Optional
 
 from pydantic import BaseModel, SecretStr
 
+STRIPE_KEY = os.getenv("STRIPE_SECRET") or os.getenv("STRIPE_API_KEY")
+STRIPE_WH = os.getenv("STRIPE_WH_SECRET")
+PROVIDER = (os.getenv("APF_PAYMENTS_PROVIDER") or os.getenv("PAYMENTS_PROVIDER", "stripe")).lower()
+
 
 class StripeConfig(BaseModel):
     secret_key: SecretStr
@@ -19,17 +23,18 @@ class AdyenConfig(BaseModel):
 
 
 class PaymentsSettings(BaseModel):
-    default_provider: str = os.getenv("PAYMENTS_PROVIDER", "stripe").lower()
+    default_provider: str = PROVIDER
+
     # optional multi-tenant/provider map hook can be added later
     stripe: Optional[StripeConfig] = (
         StripeConfig(
-            secret_key=SecretStr(os.getenv("STRIPE_SECRET", "")),
-            webhook_secret=SecretStr(os.getenv("STRIPE_WH_SECRET", "")),
+            secret_key=SecretStr(STRIPE_KEY),
+            webhook_secret=SecretStr(STRIPE_WH) if STRIPE_WH else None,
         )
-        if os.getenv("STRIPE_SECRET")
+        if STRIPE_KEY
         else None
     )
-    adyen: Optional[AdyenConfig] = None  # fill from env if you want
+    adyen: Optional[AdyenConfig] = None
 
 
 _SETTINGS: Optional[PaymentsSettings] = None
